Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(285)

Unified Diff: chrome/browser/chromeos/settings/stub_install_attributes.h

Issue 2737733003: Add Active Directory login UI tests (Closed)
Patch Set: Rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/settings/stub_install_attributes.h
diff --git a/chrome/browser/chromeos/settings/stub_install_attributes.h b/chrome/browser/chromeos/settings/stub_install_attributes.h
index 2358c2c35e090eb2759e80c0d2ed7b6e58fcf7df..c37a62b83174a241ad6ddf698e248195c917511c 100644
--- a/chrome/browser/chromeos/settings/stub_install_attributes.h
+++ b/chrome/browser/chromeos/settings/stub_install_attributes.h
@@ -21,11 +21,16 @@ class StubInstallAttributes : public InstallAttributes {
// Setup as not-yet enrolled.
void Clear();
- // Setup as consumer device. (Clears existing configuration.)
- void SetConsumer();
+ // Setup as consumer owned device. (Clears existing configuration.)
+ void SetConsumerOwned();
- // Setup as enterprise enrolled. (Clears existing configuration.)
- void SetEnterprise(const std::string& domain, const std::string& device_id);
+ // Setup as managed by Google cloud. (Clears existing configuration.)
+ void SetCloudManaged(const std::string& domain, const std::string& device_id);
+
+ // Setup as managed by Active Directory server. (Clears existing
+ // configuration.)
+ void SetActiveDirectoryManaged(const std::string& realm,
+ const std::string& device_id);
private:
DISALLOW_COPY_AND_ASSIGN(StubInstallAttributes);
@@ -40,13 +45,18 @@ class ScopedStubInstallAttributes {
static ScopedStubInstallAttributes CreateUnset();
// Factory for consumer-type ScopedStubInstallAttributes.
- static ScopedStubInstallAttributes CreateConsumer();
+ static ScopedStubInstallAttributes CreateConsumerOwned();
- // Factory for enterprise-type ScopedStubInstallAttributes.
- static ScopedStubInstallAttributes CreateEnterprise(
+ // Factory for cloud managed ScopedStubInstallAttributes.
+ static ScopedStubInstallAttributes CreateCloudManaged(
const std::string& domain,
const std::string& device_id);
+ // Factory for Active Directory managed ScopedStubInstallAttributes.
+ static ScopedStubInstallAttributes CreateActiveDirectoryManaged(
+ const std::string& realm,
+ const std::string& device_id);
+
private:
ScopedStubInstallAttributes();
};

Powered by Google App Engine
This is Rietveld 408576698